﻿-- =============================================
-- Description:	Identifies true/false if the user is a national user
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- Ken Baker     03/22/2012	     Created
-- =============================================
CREATE FUNCTION seclyr.[ufnIsNationalUser]
(
	@userId int,
	@moduleIds tinyint
)
RETURNS bit
AS
BEGIN
	DECLARE @isNationalUser bit,
			@accessLevelId tinyint;

	SET @isNationalUser = 0;
	SELECT @accessLevelId = seclyr.ufnGetAccessLevelConstant('National');
	
	IF @userId Is Null Or @userId = 0
		BEGIN
			SET @isNationalUser = 1;
		END
	ELSE
		BEGIN
			IF EXISTS (SELECT UserID 
					    FROM seclyr.UserRoles
						WHERE UserID = @userId 
						AND AccessStatus = 'Approved' 
						AND AccessLevelID = @accessLevelId
						AND (ModuleID In(SELECT [Value] FROM ufnSplit(',', @moduleIds)) OR @moduleIds IS NULL))
				BEGIN
					SET @isNationalUser = 1;
				END
		END
	RETURN @isNationalUser;
END
GO