﻿-- =============================================
-- Description:	Returns a list of weblog ADDomain rollup data for visualizations
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- =============================================
CREATE PROCEDURE [dbo].[uspRptVizWebLogADDomains]
	-- Add the parameters for the stored procedure here
	@requestDate date

AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		--get list of users via their ADDomain on a date basis
		SELECT 
			CAST(RequestDate AS Date) AS [date]
			, ADDomain
			, COUNT(Distinct UserName) AS DestinctUsers
		FROM WebLogs
		WHERE 
			RequestDate >=  @requestDate 
			AND RequestDate < DATEADD(day,1,@requestDate)
		GROUP BY CAST(RequestDate AS Date), ADDomain
		ORDER BY  1, 2
		;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the web log AD Domain visuals' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END