﻿-- =============================================
-- Description:	Returns a list oftop 5 web pages used per the web logs (IIS logs will record a lot of riff raff objects)
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- =============================================
CREATE PROCEDURE [dbo].[uspRptVizWebLogPageUsages]
	-- Add the parameters for the stored procedure here
	@requestDate date

AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		 --get top5 web page hits by @requestDate
		 --exclude Home, Terms and Conditions, and Unauthorized Pages
		 --filtering top N web pages in SSRS
		 SELECT  
			CAST(RequestDate AS date) AS RequestDate
			, RequestPage
			, COUNT(RequestPage) AS RequestPageCount
		 FROM WebLogs
		 WHERE 
			RequestDate >= @requestDate 
			AND RequestDate < DATEADD(day, 1, @requestDate)
			AND RequestPage NOT IN ('Home', 'Terms and Conditions', 'Unauthorized')
		 GROUP BY CAST(RequestDate AS date), RequestPage
		 ;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the web page usage visuals' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END