﻿-- =============================================
-- Description:	Returns a list of weblog data (weekly users) for visualizations
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- =============================================
CREATE PROCEDURE [dbo].[uspRptVizWebLogWeekly]
	-- Add the parameters for the stored procedure here
	@requestDate date

AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		--get the number of users per T-7, per day, per hour and per number of users 
		SELECT 
			CAST(RequestDate AS Date) AS UsageDate
			, COUNT(DISTINCT UserName) AS DistinctUsers
		FROM WebLogs
		WHERE 
			RequestDate >= DATEADD(day, -7, @requestDate) 
			AND RequestDate < DATEADD(day, 1, @requestDate)
		GROUP BY CAST(RequestDate AS Date)
		ORDER BY 1 DESC
		;
	END TRY
	BEGIN CATCH
		PRINT 'There was an error processing the weekly web log visuals' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END