﻿-- =============================================
-- Description:	Cleans the Locations
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- =============================================
CREATE PROCEDURE zraw.[uspDoCleanLocations]
AS
	DECLARE @TABLE_NAME varchar(100);	--make constant value for use thoughout
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON; 
	
	BEGIN TRY
		--Set @TABLE_NAME value
		SET @TABLE_NAME = 'zraw._dimLocation';

		--drop the #batchTable if it exists...
--SQL 2016 script--		DROP TABLE IF EXISTS #batchTableLocations;

--SQL 2014 script--
		--Drop temp table
		IF OBJECT_ID(N'tempdb..#batchTableLocations') IS NOT NULL
			BEGIN
				 DROP TABLE #batchTableLocations;
			END

		--need to restrict the records we modified to only those available for internalprocessing
		SELECT BatchLogID, TableName, BatchDate 
		INTO #batchTableLocations
		FROM dbo.ufnGetBatchLogsForTableProcessing ('INTPROCESSING', @TABLE_NAME);

		--LTRIM/RTRIM any string-based fields and Null out any empty strings
		UPDATE zraw._dimLocation SET
			LocationName = NULLIF(LTRIM(RTRIM(LocationName)), '')
			, LocationType = NULLIF(LTRIM(RTRIM(LocationType)), '')
			, MedicalService = NULLIF(LTRIM(RTRIM(MedicalService)), '')
			, PhysicalLocation = NULLIF(LTRIM(RTRIM(PhysicalLocation)), '')
			, SpecialAMISStop = NULLIF(LTRIM(RTRIM(SpecialAMISStop)), '')
			, CategoryOfVisit = NULLIF(LTRIM(RTRIM(CategoryOfVisit)), '')
			, VisitLocation = NULLIF(LTRIM(RTRIM(VisitLocation)), '')
			, OpCode = NULLIF(LTRIM(RTRIM(OpCode)), '')
		WHERE EXISTS (SELECT 1 FROM #batchTableLocations
			WHERE zraw._dimLocation.BatchLogID = #batchTableLocations.BatchLogID);
/**
	LocationName					varchar(50) NOT NULL,
	LocationType					varchar(50) NULL,
	MedicalService					varchar(50) NULL,
	PhysicalLocation				varchar(50)	NULL,
	SpecialAMISStop					varchar(50) NULL,
    CategoryOfVisit					varchar(50) NULL,
	VisitLocation					 varchar(50) NULL,
**/




		--set RecordStatusID based on OpCode
		UPDATE zraw._dimLocation SET
			RecordStatusID = RecordStatuses.RecordStatusID
		FROM RecordStatuses 
			INNER JOIN zraw._dimLocation ON RecordStatuses.RecordStatusCode = zraw._dimLocation.OpCode
		WHERE EXISTS (SELECT 1 FROM #batchTableLocations
			WHERE zraw._dimLocation.BatchLogID = #batchTableLocations.BatchLogID);

		--create any needed indexes to speed up cleaning
		CREATE NONCLUSTERED INDEX IX_dimLocation_LocationName ON zraw._dimLocation
			(
			LocationName
			) WITH (
				PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
				FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
				SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
				IGNORE_DUP_KEY = OFF,
				STATISTICS_NORECOMPUTE = OFF,
				STATISTICS_INCREMENTAL = OFF,
				DROP_EXISTING = OFF, 
				ONLINE = OFF,
				ALLOW_ROW_LOCKS = ON, 
				ALLOW_PAGE_LOCKS = ON,
				MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
				DATA_COMPRESSION = PAGE		--don't need, less than 10,000 rows
			)
			ON StagingIndex;

			CREATE NONCLUSTERED INDEX IX_dimLocation_LocationType ON zraw._dimLocation
			(
			LocationType
			) WITH (
				PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
				FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
				SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
				IGNORE_DUP_KEY = OFF,
				STATISTICS_NORECOMPUTE = OFF,
				STATISTICS_INCREMENTAL = OFF,
				DROP_EXISTING = OFF, 
				ONLINE = OFF,
				ALLOW_ROW_LOCKS = ON, 
				ALLOW_PAGE_LOCKS = ON,
				MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
				DATA_COMPRESSION = PAGE		--don't need, less than 10,000 rows
			)
			ON StagingIndex;

		
	
		--drop any raw index objects
		DROP INDEX IX_dimLocation_LocationName
			ON zraw._dimLocation;

		--drop any raw index objects
		DROP INDEX IX_dimLocation_LocationType
			ON zraw._dimLocation;

		--drop the #batchTableLocations if it exists...
--SQL 2016 script--		DROP TABLE IF EXISTS #batchTableLocations;

--SQL 2014 script--
		--Drop temp table
		IF OBJECT_ID(N'tempdb..#batchTableLocations') IS NOT NULL
			BEGIN
				 DROP TABLE #batchTableLocations;
			END

	END TRY
	BEGIN CATCH
		--identify that records in the batch have errored
		UPDATE BatchLogs SET 
			LoadStatus = 'INTERROR'
		WHERE EXISTS (SELECT 1 FROM #batchTableLocations
			WHERE BatchLogs.BatchLogID = #batchTableLocations.BatchLogID);

		

		--drop the #batchTableLocations if it exists...
--SQL 2016 script--		DROP TABLE IF EXISTS #batchTableLocations;

--SQL 2014 script--
		--Drop temp table
		IF OBJECT_ID(N'tempdb..#batchTableLocations') IS NOT NULL
			BEGIN
				 DROP TABLE #batchTableLocations;
			END

		PRINT 'There was an error cleaning raw Request Service data' + CHAR(13);
		THROW;
	END CATCH
END
