﻿-- =============================================
-- Description:	creates NCI indexes for ID's using page compression to load core from RAW
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
--          ---------     ----------------------------

-- =============================================
CREATE PROCEDURE zraw.[uspDoCreateRawConsultIndexesPreCoreLoad]
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	
	BEGIN TRY
	--non clustered
	--BatchLogID
	CREATE NONCLUSTERED INDEX IX_conConsult_BatchLogID ON zraw._conConsult
		(
		BatchLogID
		) WITH (
			PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
			FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
			SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
			IGNORE_DUP_KEY = OFF,
			STATISTICS_NORECOMPUTE = OFF,
			STATISTICS_INCREMENTAL = OFF,
			DROP_EXISTING = OFF, 
			ONLINE = OFF,
			ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON,
			MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
			DATA_COMPRESSION = PAGE		--use page compression; default = NONE
		)
		ON CoreIndex; 

	--StatusTypeID
	CREATE NONCLUSTERED INDEX IX_conConsult_StatusTypeID ON zraw._conConsult
		(
		StatusTypeID
		) WITH (
			PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
			FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
			SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
			IGNORE_DUP_KEY = OFF,
			STATISTICS_NORECOMPUTE = OFF,
			STATISTICS_INCREMENTAL = OFF,
			DROP_EXISTING = OFF, 
			ONLINE = OFF,
			ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON,
			MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
			DATA_COMPRESSION = PAGE		--use page compression; default = NONE
		)
		ON CoreIndex; 

    --RequestServiceID
	CREATE NONCLUSTERED INDEX IX_conConsult_RequestServiceID ON zraw._conConsult
		(
		RequestServiceID
		) WITH (
			PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
			FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
			SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
			IGNORE_DUP_KEY = OFF,
			STATISTICS_NORECOMPUTE = OFF,
			STATISTICS_INCREMENTAL = OFF,
			DROP_EXISTING = OFF, 
			ONLINE = OFF,
			ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON,
			MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
			DATA_COMPRESSION = PAGE		--use page compression; default = NONE
		)
		ON CoreIndex; 

	--StationID
	CREATE NONCLUSTERED INDEX IX_conConsult_StationID ON zraw._conConsult
		(
		StationID
		) WITH (
			PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
			FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
			SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
			IGNORE_DUP_KEY = OFF,
			STATISTICS_NORECOMPUTE = OFF,
			STATISTICS_INCREMENTAL = OFF,
			DROP_EXISTING = OFF, 
			ONLINE = OFF,
			ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON,
			MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
			DATA_COMPRESSION = PAGE		--use page compression; default = NONE
		)
		ON CoreIndex; 

    --OneConsultID
	CREATE NONCLUSTERED INDEX IX_conConsult_OneConsultID ON zraw._conConsult
		(
		OneConsultID
		) WITH (
			PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
			FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
			SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
			IGNORE_DUP_KEY = OFF,
			STATISTICS_NORECOMPUTE = OFF,
			STATISTICS_INCREMENTAL = OFF,
			DROP_EXISTING = OFF, 
			ONLINE = OFF,
			ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON,
			MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
			DATA_COMPRESSION = PAGE		--use page compression; default = NONE
		)
		ON DefFG; ---for Enclave, otherwise CoreIndex


	END TRY

	BEGIN CATCH
		PRINT 'There was an error creating NCI IDs to Load raw tables' + CHAR(13)
		SELECT * FROM dbo.ufnGetErrorInfo()
		EXEC dbo.uspRaiseErrorInfo
	END CATCH
END
