﻿CREATE TABLE dbo.AdmissionSources
(
	--source: 
		--A06.CDWWork.FBCS.ub92
			--admissionsrc

	--fields
	AdmissionSourceID		tinyint IDENTITY(1,1) NOT NULL,		--EPRS assigned (PK)
	AdmissionSourceName		varchar (100),						--SMEs will need to be able to backfill
	AdmissionSourceCode		varchar(2),							--admissionsrc
	
	--primary key
	CONSTRAINT PK_AdmissionSources PRIMARY KEY CLUSTERED 
	(
		AdmissionSourceID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys

--indexes
CREATE NONCLUSTERED INDEX IX_AdmissionSources_AdmissionSourceCode ON dbo.AdmissionSources
	(
	AdmissionSourceCode
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex
GO

--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS, source: FBCS.ub92', 
N'SCHEMA', N'dbo', 
N'TABLE', N'AdmissionSources', 
N'COLUMN', N'AdmissionSourceID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Admission source name', 
N'SCHEMA', N'dbo', 
N'TABLE', N'AdmissionSources', 
N'COLUMN', N'AdmissionSourceName'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Admission source code', 
N'SCHEMA', N'dbo', 
N'TABLE', N'AdmissionSources', 
N'COLUMN', N'AdmissionSourceCode'
GO 
