﻿CREATE TABLE dbo.DischargeStatuses
(
	--source
		--A06.CDWWork.FBCS.ub92

	--fields
	DischargeStatusID			tinyint IDENTITY(1,1) NOT NULL,		--EPRS assigned (PK)
	DischargeStatusCode			varchar(10),						--LEFT(dischargestatus, 10)
	DischargeStatusName			varchar (200),						--will have to make available for admins to fill

	--primary key
	CONSTRAINT PK_DischargeStatuses PRIMARY KEY CLUSTERED 
	(
		DischargeStatusID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys

--indexes

CREATE NONCLUSTERED INDEX IX_DischargeStatuses_DischargeStatusCode ON dbo.DischargeStatuses
	(
	DischargeStatusCode
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex
GO

--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'DischargeStatuses', 
N'COLUMN', N'DischargeStatusID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Code for the discharge status, source: dischargestatus', 
N'SCHEMA', N'dbo', 
N'TABLE', N'DischargeStatuses', 
N'COLUMN', N'DischargeStatusCode'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name for the discharge status', 
N'SCHEMA', N'dbo', 
N'TABLE', N'DischargeStatuses', 
N'COLUMN', N'DischargeStatusName'
GO 
