﻿CREATE TABLE dbo.FBCSProviders
(
	--sources:
		--A06.CDWWork.FBCS.hcfa
		--A06.CDWWork.FBCS.hcfaproviders
		--A06.CDWWork.FBCS.ub92
		--A06.CDWWork.FBCS.ub92providers

	--fields
	ProviderID					bigint IDENTITY(1,1) NOT NULL,		--EPRS assigned (PK)
	CrossMapProviderID			bigint,								--EPRS assigned (FK), references dbo.Providers
	NationalProviderIdentifier	varchar(20),						--NPI (various sources)
	FBCSHCFAStationNumber		varchar(10),						--station__no from FBCS.hcfaproviders		
	FBCSUBStationNumber			varchar(10),						--station__no from FBCS.ub92providers
	FBCSHCFAProviderNumber		bigint,								--id from FBCS.hcfa
	FBCSUBProviderNumber		bigint,								--id from FBCS.ub92providers
	ProviderName				varchar(1000),						--various provider, facility, physician fields
	AddressLine1				varchar(1000),						--Line1
	AddressLine2				varchar(1000),						--Line2
	City						varchar(5000),						--City
	[State]						varchar(50),						--State
	ZipCode						varchar(50)							--ZIP


	--primary key
	CONSTRAINT PK_FBCSProviders PRIMARY KEY CLUSTERED 
	(
		ProviderID ASC
	)
 ) 
 ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	WITH (DATA_COMPRESSION = PAGE)
GO

--foreign keys

--indexes

--CREATE NONCLUSTERED INDEX IX_FBCSProviders_ProviderName ON seclyr.FBCSProviders
--(
--	ProviderName ASC
	--) WITH (
	--	PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
	--	FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
	--	SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
	--	IGNORE_DUP_KEY = OFF,
	--	STATISTICS_NORECOMPUTE = OFF,
	--	STATISTICS_INCREMENTAL = OFF,
	--	DROP_EXISTING = OFF, 
	--	ONLINE = OFF,
	--	ALLOW_ROW_LOCKS = ON, 
	--	ALLOW_PAGE_LOCKS = ON,
	--	MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
	--	DATA_COMPRESSION = PAGE		--use page compression; default = NONE
	--)
--	ON DefinitionIndex
--GO


--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSProviders', 
N'COLUMN', N'ProviderID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Self-referential key, unique to EPRS, relates to Providers, allows administrators to cross-map/collate various providers together for report roll-ups', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSProviders', 
N'COLUMN', N'CrossMapProviderID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'National Provider Index (NPI)--individual or group/office, source: various npi-related fields', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSProviders', 
N'COLUMN', N'NationalProviderIdentifier'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name of provider, physician, facility, clinic/office', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSProviders', 
N'COLUMN', N'ProviderName'
GO

--TODO: Missing some metadata dictionary entries