﻿CREATE TABLE dbo.FBCSUBClaimConditionCodes
(
	--authoritative sources: 
		--A06.CDWWork.FBCS.UB92
           --,<conditioncode1, varchar(8000),>
           --,<conditioncode2, varchar(8000),>
           --,<conditioncode3, varchar(8000),>
           --,<conditioncode4, varchar(8000),>
           --,<conditioncode5, varchar(8000),>
           --,<conditioncode6, varchar(8000),>
           --,<conditioncode7, varchar(8000),>
           --,<conditioncode8, varchar(8000),>
           --,<conditioncode9, varchar(8000),>
           --,<conditioncode10, varchar(8000),>
           --,<conditioncode11, varchar(8000),>

	--fields
	FBCSUBClaimConditionCodeID	bigint IDENTITY(1,1) NOT NULL,	--EPRS assigned (PK)
	FBCSUBClaimID			bigint,								--EPRS assigned (FK), references FBCSUBClaims
	ConditionCodeID			smallint NOT NULL,					--EPRS assigned (FK), references ConditionCodes
	ConditionCodePositionNumber	tinyint,						--identifies the code position (1 - 11)
	BatchLogID				bigint,								--ERPS assigned (FK), references BatchLogs

    --primary key
	CONSTRAINT PK_FBCSUBClaimConditionCodes PRIMARY KEY NONCLUSTERED	--not clustered due to clust. columnstore index 
	(
		FBCSUBClaimConditionCodeID ASC
	)
) 
ON CoreData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)
GO

--foreign keys
ALTER TABLE dbo.FBCSUBClaimConditionCodes
	ADD CONSTRAINT FK_FBCSUBClaimConditionCodes_FBCSUBClaims
	FOREIGN KEY (FBCSUBClaimID)
	REFERENCES dbo.FBCSUBClaims (FBCSUBClaimID)
GO

ALTER TABLE dbo.FBCSUBClaimConditionCodes
	ADD CONSTRAINT FK_FBCSUBClaimConditionCodes_ConditionCodes
	FOREIGN KEY (ConditionCodeID)
	REFERENCES dbo.ConditionCodes (ConditionCodeID)
GO

ALTER TABLE dbo.FBCSUBClaimConditionCodes
	ADD CONSTRAINT FK_FBCSUBClaimConditionCodes_BatchLogs
	FOREIGN KEY (BatchLogID)
	REFERENCES dbo.BatchLogs (BatchLogID)
GO

--indexes
/**
	--Create clustered columnstore index that doesn't exist yet
	CREATE CLUSTERED COLUMNSTORE INDEX CCIX_FBCSUBClaimConditionCodes ON dbo.FBCSUBClaimConditionCodes
	WITH
	(
		/*DROP_EXISTING = ON	--if the index doesn't exist and this is active, 
						-- the code will go boom
		 ,*/ MAXDOP = 1		--while 0 uses max degrees of parallelism, 1 in 							
						-- this case helps tighten the ordering when 
						-- initially using a traditional clustered index
--SQL 2016--		, COMPRESSION_DELAY = 10	--in minutes; increase to 60 if doing OLTP to
						--maintain data in deltarowgroup for 60 minutes
		, DATA_COMPRESSION = COLUMNSTORE		--or COLUMNSTORE_ARCHIVE
	)
	ON CoreData			--keep the clustered columnstore with the data filegroup rather than index filegroup
	GO
**/
--TODO: Are the traditional non-clustered indexes still needed?
CREATE NONCLUSTERED INDEX IX_FBCSUBClaimConditionCodes_FBCSUBClaimID ON dbo.FBCSUBClaimConditionCodes
	(
	FBCSUBClaimID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = PAGE		--use page compression; default = NONE
	)
	ON CoreIndex
GO

CREATE NONCLUSTERED INDEX IX_FBCSUBClaimConditionCodes_ConditionCodeID ON dbo.FBCSUBClaimConditionCodes
	(
	ConditionCodeID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = PAGE		--use page compression; default = NONE
	)
	ON CoreIndex
GO

CREATE NONCLUSTERED INDEX IX_FBCSUBClaimConditionCodes_DiagnosisPositionNumber ON dbo.FBCSUBClaimConditionCodes
	(
	ConditionCodePositionNumber
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = PAGE		--use page compression; default = NONE
	)
	ON CoreIndex
GO

--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS; authoritative source table is A06.CDWWork.FBCS.ub92', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSUBClaimConditionCodes', 
N'COLUMN', N'FBCSUBClaimConditionCodeID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign key, unique to EPRS, relates to the FBCS UB Claims table',
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSUBClaimConditionCodes', 
N'COLUMN', N'FBCSUBClaimID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign key, unique to EPRS, relates to Condition Codes table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSUBClaimConditionCodes', 
N'COLUMN', N'ConditionCodeID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Position order for the condition code (e.g., Condition Code 1, 2, 3, etc.)', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSUBClaimConditionCodes', 
N'COLUMN', N'ConditionCodePositionNumber'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign key, relates to Batch Logs table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FBCSUBClaimConditionCodes', 
N'COLUMN', N'BatchLogID'
GO
