﻿CREATE TABLE dbo.FaqItems
(
	--fields
	FaqItemID		smallint IDENTITY(1,1) NOT NULL,			--EPRS assigned (PK)
	FaqCategoryID	tinyint NOT NULL,							--ERPS assigned, references FaqCategories
	CreatedByUserID	int,
	UpdatedByUserID	int,
	QuestionText	varchar (200) NULL,
	AnswerText		varchar (max) NULL,
	Popularity		smallint NULL,
	DateCreated		datetime2(7) NULL,
	DateUpdated		datetime2(7) NULL,
	Inactive		bit NOT NULL

	--primary key
	CONSTRAINT PK_FaqItems PRIMARY KEY CLUSTERED 
	(
		FaqItemID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys
ALTER TABLE dbo.FaqItems
	ADD CONSTRAINT FK_FaqItems_FaqCategoryID
	FOREIGN KEY (FaqCategoryID) 
	REFERENCES dbo.FaqCategories (FaqCategoryID)
GO

ALTER TABLE dbo.FaqItems
	ADD CONSTRAINT [FK_FaqItems_CreatedByUserID] 
	FOREIGN KEY (CreatedByUserID)
	REFERENCES seclyr.Users (UserID)
GO

ALTER TABLE dbo.FaqItems
	ADD CONSTRAINT [FK_FaqItems_UpdatedByUserID]
	FOREIGN KEY (UpdatedByUserID)
	REFERENCES seclyr.Users (UserID)
GO

--indexes
CREATE NONCLUSTERED INDEX IX_FaqItems_FaqCategoryID ON dbo.FaqItems
	(
	FaqCategoryID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex
GO

--constraints
ALTER TABLE dbo.FaqItems
   ADD CONSTRAINT DF_FaqItems_DateCreated
   DEFAULT GETDATE()
   FOR DateCreated
GO

ALTER TABLE dbo.FaqItems
   ADD CONSTRAINT DF_FaqItems_DateUpdated
   DEFAULT GETDATE()
   FOR DateUpdated
GO

ALTER TABLE dbo.FaqItems
   ADD CONSTRAINT DF_FaqItems_Inactive
   DEFAULT 0
   FOR Inactive
GO

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'FaqItemID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Faq Categories table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'FaqCategoryID'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Users table, User id who created the record', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'CreatedByUserID'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Users table, User id who created the record', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'UpdatedByUserID'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Question text', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'QuestionText'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Answer text to the question', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'AnswerText'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Integer number for specifing the relative popularity of the question for additional filtering', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'Popularity'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date the faq entry was created', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'DateCreated'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date the faq entry was last updated', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'DateUpdated'
GO 

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Indicates whether the FAQ is currently active or inactive for display', 
N'SCHEMA', N'dbo', 
N'TABLE', N'FaqItems', 
N'COLUMN', N'Inactive'
GO 

