﻿CREATE TABLE dbo.Protocols
--source sql52.spv.dim.protocol--the protocol varibale includes all urgency data items in the consult table.
-- Select distinct urgency from spv.con.Consult where urgency not in(select protocol  FROM [SPV].[Dim].[Protocol] )

(
	--fields
	ProtocolID			[int] Identity(1,1) NOT NULL,	--EPRS assigned (PK)
	StationID			[smallint] NULL,				--EPRS assigned (FK), Stations table
	RegionID		[tinyint],
	RecordStatusID					tinyint								NULL,		--EPRS assigned (Fk), referencess RecordStatuses
	Protocol	varchar(50) null,		--field changes from numbers to text; source Protocol

	--primary key
	CONSTRAINT PK_Protocols PRIMARY KEY CLUSTERED 
	(
		ProtocolID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys
ALTER TABLE dbo.Protocols
	ADD CONSTRAINT FK_Protocols_StationID
	FOREIGN KEY (StationID)
	REFERENCES dbo.Stations (StationID)
GO

ALTER TABLE dbo.Protocols
	ADD CONSTRAINT FK_Protocols_RegionID
	FOREIGN KEY (RegionID)
	REFERENCES dbo.Regions (RegionID)
GO



--indexes
CREATE NONCLUSTERED INDEX IX_Protocols_StationID ON dbo.Protocols
	(
	StationID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex

GO

CREATE NONCLUSTERED INDEX IX_Protocols_RegionID ON dbo.Protocols
	(
	RegionID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex

GO


--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'Protocols', 
N'COLUMN', N'ProtocolID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, unique to EPRS, relates to Regions table, what most VA uses',  
N'SCHEMA', N'dbo', 
N'TABLE', N'Protocols', 
N'COLUMN', N'RegionID'
GO



EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, unique to EPRS, relates to Stations table',  
N'SCHEMA', N'dbo', 
N'TABLE', N'Protocols', 
N'COLUMN', N'StationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Element used to identify urgency selected when the consult is created',  
N'SCHEMA', N'dbo', 
N'TABLE', N'Protocols', 
N'COLUMN', N'Protocol'
GO
