﻿CREATE TABLE dbo.States
(
	--fields
    StateID     TINYINT      NOT NULL,
    CCNRegionID TINYINT      NOT NULL,
    StateCode   VARCHAR (10) NOT NULL,
    StateName   VARCHAR (50) NOT NULL,

	--primary key
	CONSTRAINT PK_States PRIMARY KEY CLUSTERED 
	(
		StateID ASC
	)
)
  ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys
ALTER TABLE dbo.States
	ADD CONSTRAINT FK_States_CCNRegionID
	FOREIGN KEY (CCNRegionID)
	REFERENCES dbo.Regions (RegionID)
GO

--indexes

CREATE NONCLUSTERED INDEX IX_States_CCNRegionID ON dbo.States
	(
	CCNRegionID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 100,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex
GO

--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'States', 
N'COLUMN', N'StateID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, unique to EPRS, relates to Regions table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'States', 
N'COLUMN', N'CCNRegionID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Code for the State', 
N'SCHEMA', N'dbo', 
N'TABLE', N'States', 
N'COLUMN', N'StateCode'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name for the state', 
N'SCHEMA', N'dbo', 
N'TABLE', N'States', 
N'COLUMN', N'StateName'
GO