﻿CREATE TABLE dbo.TIUDocumentDefinitions

--No zraw table needed because we are using TIUTIUDocuments table to fill.
--Source table dim.tiudocumentdefintion sql52
(
	--fields
	TIUDocumentDefinitionID		[int] Identity(1,1) NOT NULL,	--CDW TIUDocumentDefinitionsID
	StationID					[smallint] NULL,
	TIUDocumentDefinitionName	 varchar(150) null,		--What the TIUDocument is labeled in VistA
	CDWTIUDocumentDefinitionSysNumber		int  null,
	TIUDocumentDefinitionIEN				varchar(50)	

	--primary key
	CONSTRAINT PK_TIUDocumentDefinitions PRIMARY KEY CLUSTERED 
	(
		TIUDocumentDefinitionID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--WITH (DATA_COMPRESSION = PAGE)			--less than 10,000 rows, don't need compression
GO

--foreign keys
ALTER TABLE dbo.TIUDocumentDefinitions
	ADD CONSTRAINT FK_TIUDocumentDefinitions_StationID
	FOREIGN KEY (StationID)
	REFERENCES dbo.Stations (StationID)
GO



--indexes
CREATE NONCLUSTERED INDEX IX_TIUDocumentDefinitions_StationID ON dbo.TIUDocumentDefinitions
	(
	StationID
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex

GO

CREATE NONCLUSTERED INDEX IX_TIUDocumentDefinitions_TIUDocumentDefinitionIEN ON dbo.TIUDocumentDefinitions
	(
	TIUDocumentDefinitionIEN
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = NONE		--don't need, less than 10,000 rows
	)
	ON DefinitionIndex

GO


--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'TIUDocumentDefinitions', 
N'COLUMN', N'TIUDocumentDefinitionID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'CDW system ID; source: TIUDocuementDefinitionSID',  
N'SCHEMA', N'dbo', 
N'TABLE', N'TIUDocumentDefinitions', 
N'COLUMN', N'CDWTIUDocumentDefinitionSysNumber'
GO


EXECUTE sp_addextendedproperty 
N'MS_Description', N' What the TIUDocument is labeled in VistA',  
N'SCHEMA', N'dbo', 
N'TABLE', N'TIUDocumentDefinitions', 
N'COLUMN', N'TIUDocumentDefinitionName'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'CDW station specific ID; source: TIUDocuementDefinitionIEN',  
N'SCHEMA', N'dbo', 
N'TABLE', N'TIUDocumentDefinitions', 
N'COLUMN', N'TIUDocumentDefinitionIEN'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign key, relates to Stations table, unique to EPRS', 
N'SCHEMA', N'dbo', 
N'TABLE', N'TIUDocumentDefinitions', 
N'COLUMN', N'StationID'
GO