﻿CREATE TABLE dbo.Urgencies
(
	--source: 
		--Seeddata folder with distinct urgencies per con.consult

	--fields
	UrgencyID			smallint IDENTITY(1,1)   NOT NULL,
	UrgencyName			varchar(40)					--Definition of the Urgency selected when the consult entered	    


    --primary key
	CONSTRAINT PK_Urgencies PRIMARY KEY CLUSTERED	
	(
		UrgencyID ASC
	)
) 
ON DefinitionData
	--when using clustered columnstore index, can't set data compression to PAGE
	--using data compression, we have more than 10k recs but way less than 1 million recs
	--WITH (DATA_COMPRESSION = PAGE)
GO



--foreign keys


--indexes
CREATE NONCLUSTERED INDEX IX_Urgencies_UrgencyName ON dbo.Urgencies
	(
	UrgencyName
	) WITH (
		PAD_INDEX = ON,				--If want to use a Fill Factor, then PAD_INDEX must = ON 
		FILLFACTOR = 90,			--100 = max fill; set to 90 if going to insert new values incrementally; 100 if doing bulk load
		SORT_IN_TEMPDB = ON,		-- sorts the index in the TempDB; default = OFF
		IGNORE_DUP_KEY = OFF,
		STATISTICS_NORECOMPUTE = OFF,
		STATISTICS_INCREMENTAL = OFF,
		DROP_EXISTING = OFF, 
		ONLINE = OFF,
		ALLOW_ROW_LOCKS = ON, 
		ALLOW_PAGE_LOCKS = ON,
		MAXDOP = 0,					--degrees of parallelism, controls how many CPUs to use; 0 = default (all available), max = 64
		DATA_COMPRESSION = PAGE		--use page compression; default = NONE
	)
	ON DefinitionIndex
GO




--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key, unique to EPRS, source: Con.Consult', 
N'SCHEMA', N'dbo', 
N'TABLE', N'Urgencies', 
N'COLUMN', N'UrgencyID'
GO


EXECUTE sp_addextendedproperty 
N'MS_Description', N'Definition of the Urgency selected', 
N'SCHEMA', N'dbo', 
N'TABLE', N'Urgencies', 
N'COLUMN', N'UrgencyName'
GO
